==> thirdparty-service-biz-1.0.27-2-sources.jar: cn/com/duiba/notifycenter/remoteimpl/RemoteNotifyQueueServiceImpl.java <==
package cn.com.duiba.notifycenter.remoteimpl;

import cn.com.duiba.constant.SkipNotifyConfig;
import cn.com.duiba.notifycenter.dao.NotifyQueueDAO;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.notifycenter.service.NotifyService;
import cn.com.duiba.thirdparty.api.RemoteNotifyDeveloperService;
import cn.com.duiba.thirdparty.dto.NotifyQueueDto;
import cn.com.duiba.thirdparty.enums.NotifyTypeEnum;
import cn.com.duiba.wolf.perf.timeprofile.DBTimeProfile;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.alibaba.fastjson.JSON;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RestController;

/**
 * 通知服务接口
 */
@RestController
public class RemoteNotifyQueueServiceImpl implements RemoteNotifyDeveloperService {

	private static Logger log = LoggerFactory.getLogger(RemoteNotifyQueueServiceImpl.class);

	@Autowired
	private NotifyQueueDAO notifyQueueDAO;
	@Autowired
	private NotifyService notifyService;

	@Autowired
	private SkipNotifyConfig skipNotifyConfig;

	@Override
	public void notifyDeveloper(NotifyQueueDto notifyQueue) {
		try {
			if (skipNotifyConfig.hasNotNotify(notifyQueue.getAppId())) {
				log.info("the app skip notify, appId={}", notifyQueue.getAppId());
				return;
			}

			NotifyQueueDO queue = BeanUtils.copy(notifyQueue, NotifyQueueDO.class);
			DBTimeProfile.enter("insert");
			if(queue.getTimes() == null){
                queue.setTimes(0);
			}
			if(queue.getNotifyType() == null){//默认结果通知，向上兼容
				queue.setNotifyType(NotifyTypeEnum.NOTIFY_RESULT.getCode());
			}
			if(NotifyTypeEnum.getByCode(queue.getNotifyType())==null){
				throw new Exception("通知类型不存在;queue:"+ JSON.toJSONString(queue));
			}

			String errorMsg = queue.getError4developer();
			if(StringUtils.isNotBlank(errorMsg) && errorMsg.length() > 600){
				queue.setError4developer(errorMsg.substring(0, 600));
			}
			notifyQueueDAO.insert(queue);
			DBTimeProfile.release();
			DBTimeProfile.enter("notify");
			notifyService.notify(queue, "remote call");
			DBTimeProfile.release();
		} catch (Exception e) {
			log.error("notify error", e);
		}
	}
}

==> thirdparty-service-biz-1.0.33.p2-20211015.034711-1-sources.jar: cn/com/duiba/notifycenter/remoteimpl/RemoteNotifyQueueServiceImpl.java <==
package cn.com.duiba.notifycenter.remoteimpl;

import cn.com.duiba.constant.DelayNotifyConfig;
import cn.com.duiba.constant.SkipNotifyConfig;
import cn.com.duiba.constant.WandaConfig;
import cn.com.duiba.mq.RocketMQMsgProducer;
import cn.com.duiba.mq.RocketMQTopicConstant;
import cn.com.duiba.notifycenter.dao.NotifyQueueDAO;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.notifycenter.service.NotifyService;
import cn.com.duiba.thirdparty.api.RemoteNotifyDeveloperService;
import cn.com.duiba.thirdparty.dto.NotifyQueueDto;
import cn.com.duiba.thirdparty.enums.DelayMsgConfigNameEnum;
import cn.com.duiba.thirdparty.enums.NotifyTypeEnum;
import cn.com.duiba.wolf.perf.timeprofile.DBTimeProfile;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RestController;

import java.util.Optional;

/**
 * 通知服务接口
 */
@RestController
public class RemoteNotifyQueueServiceImpl implements RemoteNotifyDeveloperService {

	private static Logger log = LoggerFactory.getLogger(RemoteNotifyQueueServiceImpl.class);

	@Autowired
	private NotifyQueueDAO notifyQueueDAO;
	@Autowired
	private NotifyService notifyService;

	@Autowired
	private SkipNotifyConfig skipNotifyConfig;

	@Autowired
	private DelayNotifyConfig delayNotifyConfig;

	@Autowired
	private RocketMQMsgProducer rocketMQMsgProducer;

	@Autowired
	private RocketMQTopicConstant rocketMQTopicConstant;

	@Override
	public void notifyDeveloper(NotifyQueueDto notifyQueue) {
		try {
			if (skipNotifyConfig.hasNotNotify(notifyQueue.getAppId(), notifyQueue.getResult())) {
				log.info("the app skip notify, appId={}", notifyQueue.getAppId());
				return;
			}

			NotifyQueueDO queue = BeanUtils.copy(notifyQueue, NotifyQueueDO.class);
			DBTimeProfile.enter("insert");
			if(queue.getTimes() == null){
                queue.setTimes(0);
			}
			if(queue.getNotifyType() == null){//默认结果通知，向上兼容
				queue.setNotifyType(NotifyTypeEnum.NOTIFY_RESULT.getCode());
			}
			if(NotifyTypeEnum.getByCode(queue.getNotifyType())==null){
				throw new Exception("通知类型不存在;queue:"+ JSON.toJSONString(queue));
			}

			String errorMsg = queue.getError4developer();
			if(StringUtils.isNotBlank(errorMsg) && errorMsg.length() > 600){
				queue.setError4developer(errorMsg.substring(0, 600));
			}
			//判断消息是否需要延时发送
			if (delayNotifyConfig.ifNeedDelay(queue.getAppId())) {
				log.info("[万达酒店] remote延时发送");
				JSONObject json = (JSONObject) JSONObject.toJSON(queue);
				Integer delayLevel = Optional.ofNullable(DelayNotifyConfig.getDelayLevels(queue.getAppId())).orElse(0);
				json.put(DelayMsgConfigNameEnum.DELAY_LEVEL.getName(), delayLevel);
				rocketMQMsgProducer.sendMsg(rocketMQTopicConstant.getDelayMsg(), "remote", "", json.toJSONString(), false, null);
				DBTimeProfile.release();
				return;
			}
			notifyQueueDAO.insert(queue);
			DBTimeProfile.release();
			DBTimeProfile.enter("notify");
			notifyService.notify(queue, "remote call");
			DBTimeProfile.release();
		} catch (Exception e) {
			log.error("notify error", e);
		}
	}
}
